==> uke-admin-web-scaffold-1.2.0-rc8.tgz: package/plugins/version-com.js <==
/* eslint-disable react/no-multi-comp */
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import React, { Component } from 'react';
import { ShowModal, TipPanel, Notify } from '../ui-refs';
var VersionChecker = /** @class */ (function (_super) {
    __extends(VersionChecker, _super);
    function VersionChecker(props) {
        var _this = _super.call(this, props) || this;
        _this._clear = function () {
            _this.timer && clearInterval(_this.timer);
        };
        _this.getVersion = function () {
            var versionUrl = _this.props.versionUrl;
            if (!versionUrl)
                return console.log('请设置版本文件地址 versionUrl');
            if (_this.errorCount === 5)
                return _this._clear();
            fetch(versionUrl + "?t=" + Date.now())
                .then(function (res) { return res.json(); })
                .then(function (remoteVersion) {
                var numberVersion = remoteVersion.numberVersion, updateLog = remoteVersion.updateLog;
                numberVersion = numberVersion.trim();
                if (numberVersion != _this.state.lastVersion) {
                    _this._clear();
                    Notify({
                        config: {
                            text: '有新的系统版本',
                            title: '系统通知',
                            type: 'success',
                            timer: 0,
                            onClickTip: function (e) {
                                _this.reload();
                            },
                            actionText: '更新',
                        }
                    });
                    !_this.__unmount && _this.setState({
                        lastVersion: numberVersion,
                        updateLog: updateLog
                    });
                }
            })
                .catch(function (e) {
                _this.errorCount++;
            });
        };
        _this.reload = function () {
            var _a = _this.state, updateLog = _a.updateLog, lastVersion = _a.lastVersion;
            ShowModal({
                title: '是否更新版本？',
                type: 'confirm',
                width: 400,
                confirmText: (React.createElement("div", null,
                    React.createElement("div", null,
                        React.createElement("h4", null, "\u66F4\u65B0\u5185\u5BB9:"),
                        React.createElement("p", null, updateLog || '日常更新')),
                    React.createElement("hr", null),
                    React.createElement(TipPanel, { type: "success", text: "\u8BF7\u786E\u4FDD\u5DF2\u4FDD\u5B58\u5DE5\u4F5C\u5185\u5BB9\uFF0C\u9875\u9762\u5373\u5C06\u5237\u65B0" }))),
                onConfirm: function (isSure) {
                    if (isSure) {
                        location.reload();
                    }
                },
            });
        };
        _this.render = function () {
            return React.createElement("span", null);
        };
        var numberVersion = props.versionInfo.numberVersion;
        window.__VERSION = props.versionInfo;
        numberVersion = numberVersion.trim();
        _this.errorCount = 0;
        _this.state = {
            currVersion: numberVersion,
            lastVersion: numberVersion,
        };
        return _this;
    }
    VersionChecker.prototype.componentDidMount = function () {
        this.getVersion();
        this.timer = setInterval(this.getVersion, 30 * 60 * 1000);
    };
    VersionChecker.prototype.componentWillUnmount = function () {
        this.__unmount = true;
        this._clear();
    };
    return VersionChecker;
}(Component));
var VersionDisplayer = function (props) {
    var versionInfo = props.versionInfo, $T = props.$T;
    return (React.createElement("div", { className: "version-container" },
        React.createElement("div", null,
            $T('当前版本'),
            " ",
            versionInfo.numberVersion),
        React.createElement("div", null,
            "\u00A9 2018 - ",
            (new Date()).getFullYear())));
};
export { VersionChecker };
export default VersionDisplayer;

==> uke-admin-web-scaffold-1.2.4.tgz: package/plugins/version-com.js <==
/* eslint-disable react/no-multi-comp */
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import React, { Component } from 'react';
import { ShowModal, Alert, Notify } from '../ui-refs';
var VersionChecker = /** @class */ (function (_super) {
    __extends(VersionChecker, _super);
    function VersionChecker(props) {
        var _this = _super.call(this, props) || this;
        _this._clear = function () {
            _this.timer && clearInterval(_this.timer);
        };
        _this.getVersion = function () {
            var versionUrl = _this.props.versionUrl;
            if (!versionUrl)
                return console.log('请设置版本文件地址 versionUrl');
            if (_this.errorCount === 5)
                return _this._clear();
            fetch(versionUrl + "?t=" + Date.now())
                .then(function (res) { return res.json(); })
                .then(function (remoteVersion) {
                var numberVersion = remoteVersion.numberVersion, updateLog = remoteVersion.updateLog;
                numberVersion = numberVersion.trim();
                if (numberVersion != _this.state.lastVersion) {
                    _this._clear();
                    Notify({
                        config: {
                            text: '有新的系统版本',
                            title: '系统通知',
                            type: 'success',
                            timer: 0,
                            onClickTip: function (e) {
                                _this.reload();
                            },
                            actionText: '更新',
                        }
                    });
                    !_this.__unmount && _this.setState({
                        lastVersion: numberVersion,
                        updateLog: updateLog
                    });
                }
            })
                .catch(function (e) {
                _this.errorCount++;
            });
        };
        _this.reload = function () {
            var _a = _this.state, updateLog = _a.updateLog, lastVersion = _a.lastVersion;
            ShowModal({
                title: '是否更新版本？',
                type: 'confirm',
                width: 400,
                confirmText: (React.createElement("div", null,
                    React.createElement("div", null,
                        React.createElement("h4", null, "\u66F4\u65B0\u5185\u5BB9:"),
                        React.createElement("p", null, updateLog || '日常更新')),
                    React.createElement("hr", null),
                    React.createElement(Alert, { type: "success", text: "\u8BF7\u786E\u4FDD\u5DF2\u4FDD\u5B58\u5DE5\u4F5C\u5185\u5BB9\uFF0C\u9875\u9762\u5373\u5C06\u5237\u65B0" }))),
                onConfirm: function (isSure) {
                    if (isSure) {
                        location.reload();
                    }
                },
            });
        };
        _this.render = function () {
            return React.createElement("span", null);
        };
        var numberVersion = props.versionInfo.numberVersion;
        window.__VERSION = props.versionInfo;
        numberVersion = numberVersion.trim();
        _this.errorCount = 0;
        _this.state = {
            currVersion: numberVersion,
            lastVersion: numberVersion,
        };
        return _this;
    }
    VersionChecker.prototype.componentDidMount = function () {
        this.getVersion();
        this.timer = setInterval(this.getVersion, 30 * 60 * 1000);
    };
    VersionChecker.prototype.componentWillUnmount = function () {
        this.__unmount = true;
        this._clear();
    };
    return VersionChecker;
}(Component));
var VersionDisplayer = function (props) {
    var versionInfo = props.versionInfo, $T = props.$T;
    return (React.createElement("div", { className: "version-container" },
        React.createElement("div", null,
            $T('当前版本'),
            " ",
            versionInfo.numberVersion),
        React.createElement("div", null,
            "\u00A9 2018 - ",
            (new Date()).getFullYear())));
};
export { VersionChecker };
export default VersionDisplayer;
